.. _community_guidelines:
.. index:: Community Guidelines

Community guidelines
********************

* Contributions to :program:`PyTessel` are always welcome and appreciated. Before doing
  so, please first read the `CONTRIBUTING <https://github.com/ifilot/pytessel/blob/master/CONTRIBUTING.md>`_
  guide.
* For reporting issues or problems with the software, you are kindly invited to
  `to open a new issue on Github with the bug tag <https://github.com/ifilot/pytessel/issues/new?labels=bug>`_.
* If you seek support in using :program:`PyTessel`, please
  `open an issue with the question tag <https://github.com/ifilot/pytessel/issues/new?labels=question>`_.
* If you wish to contact the developers, please send an e-mail to i.a.w.filot@tue.nl.
